pub fn resolve_backup_selector(
registry: &[RegistryEntry],
selector: &str,
) -> Result<String, BackupPlanError>Expand description
Resolve an operator selector to one concrete live registry canister id.
pub fn resolve_backup_selector(
registry: &[RegistryEntry],
selector: &str,
) -> Result<String, BackupPlanError>Resolve an operator selector to one concrete live registry canister id.