Module restore

Module restore 

Structs

RestoreApplyArtifactCheck
RestoreApplyArtifactCheck
RestoreApplyArtifactValidation
RestoreApplyArtifactValidation
RestoreApplyCommandConfig
RestoreApplyCommandConfig
RestoreApplyCommandOutput
RestoreApplyCommandOutput
RestoreApplyCommandPreview
RestoreApplyCommandPreview
RestoreApplyDryRun
RestoreApplyDryRun
RestoreApplyDryRunOperation
RestoreApplyDryRunOperation
RestoreApplyJournal
RestoreApplyJournal
RestoreApplyJournalOperation
RestoreApplyJournalOperation
RestoreApplyOperationKindCounts
RestoreApplyOperationKindCounts
RestoreApplyOperationReceipt
RestoreApplyOperationReceipt
RestoreApplyPendingSummary
RestoreApplyPendingSummary
RestoreApplyProgressSummary
RestoreApplyProgressSummary
RestoreApplyReportOperation
RestoreApplyReportOperation
RestoreApplyRunnerCommand
RestoreApplyRunnerCommand
RestoreIdentitySummary
RestoreIdentitySummary
RestoreMapping
RestoreMapping
RestoreMappingEntry
RestoreMappingEntry
RestoreOperationSummary
RestoreOperationSummary
RestoreOrderingDependency
RestoreOrderingDependency
RestoreOrderingSummary
RestoreOrderingSummary
RestorePlan
RestorePlan
RestorePlanMember
RestorePlanMember
RestorePlanner
RestorePlanner
RestoreReadinessSummary
RestoreReadinessSummary
RestoreRunExecutedOperation
RestoreRunExecutedOperation
RestoreRunOperationReceipt
RestoreRunOperationReceipt
RestoreRunReceiptSummary
RestoreRunReceiptSummary
RestoreRunResponse
RestoreRunResponse
RestoreRunnerConfig
RestoreRunnerConfig
RestoreRunnerOutcome
RestoreRunnerOutcome
RestoreSnapshotSummary
RestoreSnapshotSummary
RestoreVerificationSummary
RestoreVerificationSummary

Enums

RestoreApplyDryRunError
RestoreApplyDryRunError
RestoreApplyJournalError
RestoreApplyJournalError
RestoreApplyOperationKind
RestoreApplyOperationKind
RestoreApplyOperationReceiptOutcome
RestoreApplyOperationReceiptOutcome
RestoreApplyOperationState
RestoreApplyOperationState
RestoreApplyReportOutcome
RestoreApplyReportOutcome
RestoreOrderingRelationship
RestoreOrderingRelationship
RestorePlanError
RestorePlanError
RestoreRunnerError
RestoreRunnerError

Constants

RESTORE_RUN_RECEIPT_COMPLETED
RESTORE_RUN_RECEIPT_FAILED
RESTORE_RUN_RECEIPT_RECOVERED_PENDING

Functions

parse_uploaded_snapshot_id
restore_run_dry_run
Build a no-mutation native restore runner preview from a journal file.
restore_run_execute
Execute ready restore apply journal operations through generated runner commands.
restore_run_execute_result
restore_run_unclaim_pending
Recover an interrupted restore runner by unclaiming the pending operation.