pub struct RestoreApplyJournal {
pub journal_version: u16,
pub backup_id: String,
pub ready: bool,
pub blocked_reasons: Vec<String>,
pub operation_count: usize,
pub operation_counts: RestoreApplyOperationKindCounts,
pub pending_operations: usize,
pub ready_operations: usize,
pub blocked_operations: usize,
pub completed_operations: usize,
pub failed_operations: usize,
pub operations: Vec<RestoreApplyJournalOperation>,
}Expand description
RestoreApplyJournal
Fields
journal_version: u16backup_id: Stringready: boolblocked_reasons: Vec<String>operation_count: usizeoperation_counts: RestoreApplyOperationKindCountspending_operations: usizeready_operations: usizeblocked_operations: usizecompleted_operations: usizefailed_operations: usizeoperations: Vec<RestoreApplyJournalOperation>Implementations
Sourceimpl RestoreApplyJournal
impl RestoreApplyJournal
Sourcepub fn from_dry_run(dry_run: &RestoreApplyDryRun) -> Self
pub fn from_dry_run(dry_run: &RestoreApplyDryRun) -> Self
Build the initial no-mutation restore apply journal from a dry-run.
Sourcepub fn validate(&self) -> Result<(), RestoreApplyJournalError>
pub fn validate(&self) -> Result<(), RestoreApplyJournalError>
Validate the structural consistency of a restore apply journal.
Sourcepub fn status(&self) -> RestoreApplyJournalStatus
pub fn status(&self) -> RestoreApplyJournalStatus
Summarize this apply journal for operators and automation.
Sourcepub fn report(&self) -> RestoreApplyJournalReport
pub fn report(&self) -> RestoreApplyJournalReport
Build an operator-oriented report from this apply journal.
Sourcepub fn next_ready_operation(&self) -> Option<&RestoreApplyJournalOperation>
pub fn next_ready_operation(&self) -> Option<&RestoreApplyJournalOperation>
Return the full next ready operation row, if one is available.
Sourcepub fn next_transition_operation(&self) -> Option<&RestoreApplyJournalOperation>
pub fn next_transition_operation(&self) -> Option<&RestoreApplyJournalOperation>
Return the next ready or pending operation that controls runner progress.
Sourcepub fn next_operation(&self) -> RestoreApplyNextOperation
pub fn next_operation(&self) -> RestoreApplyNextOperation
Render the next transitionable operation as a compact runner response.
Sourcepub fn next_command_preview(&self) -> RestoreApplyCommandPreview
pub fn next_command_preview(&self) -> RestoreApplyCommandPreview
Render the next transitionable operation as a no-execute command preview.
Sourcepub fn next_command_preview_with_config(
&self,
config: &RestoreApplyCommandConfig,
) -> RestoreApplyCommandPreview
pub fn next_command_preview_with_config( &self, config: &RestoreApplyCommandConfig, ) -> RestoreApplyCommandPreview
Render the next transitionable operation with a configured command preview.
Sourcepub fn mark_next_operation_pending(
&mut self,
) -> Result<(), RestoreApplyJournalError>
pub fn mark_next_operation_pending( &mut self, ) -> Result<(), RestoreApplyJournalError>
Mark the next transitionable operation pending and refresh journal counts.
Sourcepub fn mark_next_operation_pending_at(
&mut self,
updated_at: Option<String>,
) -> Result<(), RestoreApplyJournalError>
pub fn mark_next_operation_pending_at( &mut self, updated_at: Option<String>, ) -> Result<(), RestoreApplyJournalError>
Mark the next transitionable operation pending with an update marker.
Sourcepub fn mark_operation_pending(
&mut self,
sequence: usize,
) -> Result<(), RestoreApplyJournalError>
pub fn mark_operation_pending( &mut self, sequence: usize, ) -> Result<(), RestoreApplyJournalError>
Mark one restore apply operation pending and refresh journal counts.
Sourcepub fn mark_operation_pending_at(
&mut self,
sequence: usize,
updated_at: Option<String>,
) -> Result<(), RestoreApplyJournalError>
pub fn mark_operation_pending_at( &mut self, sequence: usize, updated_at: Option<String>, ) -> Result<(), RestoreApplyJournalError>
Mark one restore apply operation pending with an update marker.
Sourcepub fn mark_next_operation_ready(
&mut self,
) -> Result<(), RestoreApplyJournalError>
pub fn mark_next_operation_ready( &mut self, ) -> Result<(), RestoreApplyJournalError>
Mark the current pending operation ready again and refresh counts.
Sourcepub fn mark_next_operation_ready_at(
&mut self,
updated_at: Option<String>,
) -> Result<(), RestoreApplyJournalError>
pub fn mark_next_operation_ready_at( &mut self, updated_at: Option<String>, ) -> Result<(), RestoreApplyJournalError>
Mark the current pending operation ready again with an update marker.
Sourcepub fn mark_operation_ready(
&mut self,
sequence: usize,
) -> Result<(), RestoreApplyJournalError>
pub fn mark_operation_ready( &mut self, sequence: usize, ) -> Result<(), RestoreApplyJournalError>
Mark one restore apply operation ready again and refresh journal counts.
Sourcepub fn mark_operation_ready_at(
&mut self,
sequence: usize,
updated_at: Option<String>,
) -> Result<(), RestoreApplyJournalError>
pub fn mark_operation_ready_at( &mut self, sequence: usize, updated_at: Option<String>, ) -> Result<(), RestoreApplyJournalError>
Mark one restore apply operation ready again with an update marker.
Sourcepub fn mark_operation_completed(
&mut self,
sequence: usize,
) -> Result<(), RestoreApplyJournalError>
pub fn mark_operation_completed( &mut self, sequence: usize, ) -> Result<(), RestoreApplyJournalError>
Mark one restore apply operation completed and refresh journal counts.
Sourcepub fn mark_operation_completed_at(
&mut self,
sequence: usize,
updated_at: Option<String>,
) -> Result<(), RestoreApplyJournalError>
pub fn mark_operation_completed_at( &mut self, sequence: usize, updated_at: Option<String>, ) -> Result<(), RestoreApplyJournalError>
Mark one restore apply operation completed with an update marker.
Sourcepub fn mark_operation_failed(
&mut self,
sequence: usize,
reason: String,
) -> Result<(), RestoreApplyJournalError>
pub fn mark_operation_failed( &mut self, sequence: usize, reason: String, ) -> Result<(), RestoreApplyJournalError>
Mark one restore apply operation failed and refresh journal counts.
Sourcepub fn mark_operation_failed_at(
&mut self,
sequence: usize,
reason: String,
updated_at: Option<String>,
) -> Result<(), RestoreApplyJournalError>
pub fn mark_operation_failed_at( &mut self, sequence: usize, reason: String, updated_at: Option<String>, ) -> Result<(), RestoreApplyJournalError>
Mark one restore apply operation failed with an update marker.