pub struct RestoreApplyOperationKindCounts {
pub snapshot_uploads: usize,
pub snapshot_loads: usize,
pub code_reinstalls: usize,
pub member_verifications: usize,
pub fleet_verifications: usize,
pub verification_operations: usize,
}Expand description
RestoreApplyOperationKindCounts
Fields
snapshot_uploads: usizesnapshot_loads: usizecode_reinstalls: usizemember_verifications: usizefleet_verifications: usizeverification_operations: usizeImplementations
Sourceimpl RestoreApplyOperationKindCounts
impl RestoreApplyOperationKindCounts
Sourcepub fn from_operations(operations: &[RestoreApplyJournalOperation]) -> Self
pub fn from_operations(operations: &[RestoreApplyJournalOperation]) -> Self
Count restore apply journal operations by runner operation kind.
Sourcepub fn validate_matches_if_supplied(
&self,
expected: &Self,
) -> Result<(), RestoreApplyJournalError>
pub fn validate_matches_if_supplied( &self, expected: &Self, ) -> Result<(), RestoreApplyJournalError>
Validate this count object against concrete operations when it was supplied.
Sourcepub fn from_dry_run_phases(phases: &[RestoreApplyDryRunPhase]) -> Self
pub fn from_dry_run_phases(phases: &[RestoreApplyDryRunPhase]) -> Self
Count restore apply dry-run operations by runner operation kind.