pub struct RestoreRunnerCommandOutput {
pub success: bool,
pub status: String,
pub stdout: Vec<u8>,
pub stderr: Vec<u8>,
}Expand description
RestoreRunnerCommandOutput
Process-like command output returned by a restore runner executor. Owned by restore runner execution and converted into durable receipts.
Fields
success: boolstatus: Stringstdout: Vec<u8>stderr: Vec<u8>Trait Implementations
Sourceimpl Clone for RestoreRunnerCommandOutput
impl Clone for RestoreRunnerCommandOutput
Sourceimpl Debug for RestoreRunnerCommandOutput
impl Debug for RestoreRunnerCommandOutput
impl Eq for RestoreRunnerCommandOutput
impl StructuralPartialEq for RestoreRunnerCommandOutput