pub trait BackupRunnerExecutor {
// Required methods
fn preflight_receipts(
&mut self,
plan: &BackupPlan,
preflight_id: &str,
validated_at: &str,
expires_at: &str,
) -> Result<BackupExecutionPreflightReceipts, BackupRunnerCommandError>;
fn canister_status(
&mut self,
canister_id: &str,
) -> Result<BackupRunnerCanisterStatus, BackupRunnerCommandError>;
fn snapshot_inventory(
&mut self,
canister_id: &str,
) -> Result<Vec<BackupRunnerSnapshot>, BackupRunnerCommandError>;
fn stop_canister(
&mut self,
canister_id: &str,
command_lifetime: CommandLifetimeHandle,
) -> Result<(), BackupRunnerCommandError>;
fn start_canister(
&mut self,
canister_id: &str,
command_lifetime: CommandLifetimeHandle,
) -> Result<(), BackupRunnerCommandError>;
fn create_snapshot(
&mut self,
canister_id: &str,
command_lifetime: CommandLifetimeHandle,
) -> Result<BackupRunnerSnapshot, BackupRunnerCommandError>;
fn download_snapshot(
&mut self,
canister_id: &str,
snapshot_id: &str,
artifact_path: &Path,
command_lifetime: CommandLifetimeHandle,
) -> Result<(), BackupRunnerCommandError>;
}Expand description
BackupRunnerExecutor
Required Methods
Sourcefn preflight_receipts(
&mut self,
plan: &BackupPlan,
preflight_id: &str,
validated_at: &str,
expires_at: &str,
) -> Result<BackupExecutionPreflightReceipts, BackupRunnerCommandError>
fn preflight_receipts( &mut self, plan: &BackupPlan, preflight_id: &str, validated_at: &str, expires_at: &str, ) -> Result<BackupExecutionPreflightReceipts, BackupRunnerCommandError>
Prove execution preflights before any mutating operation runs.
Sourcefn canister_status(
&mut self,
canister_id: &str,
) -> Result<BackupRunnerCanisterStatus, BackupRunnerCommandError>
fn canister_status( &mut self, canister_id: &str, ) -> Result<BackupRunnerCanisterStatus, BackupRunnerCommandError>
Observe one canister’s authoritative lifecycle status.
Sourcefn snapshot_inventory(
&mut self,
canister_id: &str,
) -> Result<Vec<BackupRunnerSnapshot>, BackupRunnerCommandError>
fn snapshot_inventory( &mut self, canister_id: &str, ) -> Result<Vec<BackupRunnerSnapshot>, BackupRunnerCommandError>
Observe the authoritative snapshots currently retained for one canister.
Sourcefn stop_canister(
&mut self,
canister_id: &str,
command_lifetime: CommandLifetimeHandle,
) -> Result<(), BackupRunnerCommandError>
fn stop_canister( &mut self, canister_id: &str, command_lifetime: CommandLifetimeHandle, ) -> Result<(), BackupRunnerCommandError>
Stop one selected canister.
Sourcefn start_canister(
&mut self,
canister_id: &str,
command_lifetime: CommandLifetimeHandle,
) -> Result<(), BackupRunnerCommandError>
fn start_canister( &mut self, canister_id: &str, command_lifetime: CommandLifetimeHandle, ) -> Result<(), BackupRunnerCommandError>
Start one selected canister.
Sourcefn create_snapshot(
&mut self,
canister_id: &str,
command_lifetime: CommandLifetimeHandle,
) -> Result<BackupRunnerSnapshot, BackupRunnerCommandError>
fn create_snapshot( &mut self, canister_id: &str, command_lifetime: CommandLifetimeHandle, ) -> Result<BackupRunnerSnapshot, BackupRunnerCommandError>
Create one selected canister snapshot and return the typed snapshot receipt.
Sourcefn download_snapshot(
&mut self,
canister_id: &str,
snapshot_id: &str,
artifact_path: &Path,
command_lifetime: CommandLifetimeHandle,
) -> Result<(), BackupRunnerCommandError>
fn download_snapshot( &mut self, canister_id: &str, snapshot_id: &str, artifact_path: &Path, command_lifetime: CommandLifetimeHandle, ) -> Result<(), BackupRunnerCommandError>
Download one selected snapshot into a temporary artifact directory.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".