pub struct BackupLayout { /* private fields */ }Expand description
BackupLayout
Implementations
Sourceimpl BackupLayout
impl BackupLayout
Sourcepub const fn new(root: PathBuf) -> Self
pub const fn new(root: PathBuf) -> Self
Create a filesystem layout rooted at one backup directory.
Sourcepub fn manifest_path(&self) -> PathBuf
pub fn manifest_path(&self) -> PathBuf
Return the canonical manifest path for this backup layout.
Sourcepub fn journal_path(&self) -> PathBuf
pub fn journal_path(&self) -> PathBuf
Return the canonical mutable journal path for this backup layout.
Sourcepub fn write_manifest(
&self,
manifest: &FleetBackupManifest,
) -> Result<(), PersistenceError>
pub fn write_manifest( &self, manifest: &FleetBackupManifest, ) -> Result<(), PersistenceError>
Write a validated manifest with atomic replace semantics.
Sourcepub fn read_manifest(&self) -> Result<FleetBackupManifest, PersistenceError>
pub fn read_manifest(&self) -> Result<FleetBackupManifest, PersistenceError>
Read and validate a manifest from this backup layout.
Sourcepub fn write_journal(
&self,
journal: &DownloadJournal,
) -> Result<(), PersistenceError>
pub fn write_journal( &self, journal: &DownloadJournal, ) -> Result<(), PersistenceError>
Write a validated download journal with atomic replace semantics.
Sourcepub fn read_journal(&self) -> Result<DownloadJournal, PersistenceError>
pub fn read_journal(&self) -> Result<DownloadJournal, PersistenceError>
Read and validate a download journal from this backup layout.