pub struct BackupPlan {Show 15 fields
pub plan_id: String,
pub run_id: String,
pub fleet: String,
pub network: String,
pub root_canister_id: String,
pub selected_subtree_root: Option<String>,
pub selected_scope_kind: BackupScopeKind,
pub include_descendants: bool,
pub root_included: bool,
pub requires_root_controller: bool,
pub snapshot_read_authority: SnapshotReadAuthority,
pub quiescence_policy: QuiescencePolicy,
pub topology_hash_before_quiesce: String,
pub targets: Vec<BackupTarget>,
pub phases: Vec<BackupOperation>,
}Expand description
BackupPlan
Fields
plan_id: Stringrun_id: Stringfleet: Stringnetwork: Stringroot_canister_id: Stringselected_subtree_root: Option<String>selected_scope_kind: BackupScopeKindinclude_descendants: boolroot_included: boolrequires_root_controller: boolquiescence_policy: QuiescencePolicytopology_hash_before_quiesce: Stringtargets: Vec<BackupTarget>phases: Vec<BackupOperation>Implementations
Sourceimpl BackupPlan
impl BackupPlan
Sourcepub fn validate_execution_preflight_receipts(
&self,
topology_receipt: &TopologyPreflightReceipt,
quiescence_receipt: &QuiescencePreflightReceipt,
preflight_id: &str,
as_of: &str,
) -> Result<(), BackupPlanError>
pub fn validate_execution_preflight_receipts( &self, topology_receipt: &TopologyPreflightReceipt, quiescence_receipt: &QuiescencePreflightReceipt, preflight_id: &str, as_of: &str, ) -> Result<(), BackupPlanError>
Validate execution-only preflight receipts before mutation starts.
Sourcepub fn apply_execution_preflight_receipts(
&mut self,
receipts: &BackupExecutionPreflightReceipts,
as_of: &str,
) -> Result<(), BackupPlanError>
pub fn apply_execution_preflight_receipts( &mut self, receipts: &BackupExecutionPreflightReceipts, as_of: &str, ) -> Result<(), BackupPlanError>
Apply and validate the full execution preflight receipt bundle.
Apply proven authority receipts produced by execution preflights.
Apply proven control authority receipts for every selected target.
Apply proven snapshot read authority receipts for every selected target.
Build the typed control-authority preflight request for this plan.
Build the typed snapshot-read preflight request for this plan.
Sourcepub fn topology_preflight_request(&self) -> TopologyPreflightRequest
pub fn topology_preflight_request(&self) -> TopologyPreflightRequest
Build the typed topology preflight request for this plan.
Sourcepub fn quiescence_preflight_request(&self) -> QuiescencePreflightRequest
pub fn quiescence_preflight_request(&self) -> QuiescencePreflightRequest
Build the typed quiescence preflight request for this plan.
Sourceimpl BackupPlan
impl BackupPlan
Sourcepub fn validate(&self) -> Result<(), BackupPlanError>
pub fn validate(&self) -> Result<(), BackupPlanError>
Validate the backup plan as a dry-run/planning artifact.
Sourcepub fn validate_for_execution(&self) -> Result<(), BackupPlanError>
pub fn validate_for_execution(&self) -> Result<(), BackupPlanError>
Validate the backup plan before any live mutation can run.