pub struct RestoreApplyJournal {Show 14 fields
pub journal_version: u16,
pub backup_id: String,
pub ready: bool,
pub blocked_reasons: Vec<String>,
pub backup_root: Option<String>,
pub operation_count: usize,
pub operation_counts: RestoreApplyOperationKindCounts,
pub pending_operations: usize,
pub ready_operations: usize,
pub blocked_operations: usize,
pub completed_operations: usize,
pub failed_operations: usize,
pub operations: Vec<RestoreApplyJournalOperation>,
pub operation_receipts: Vec<RestoreApplyOperationReceipt>,
}Expand description
RestoreApplyJournal
Fields
journal_version: u16backup_id: Stringready: boolblocked_reasons: Vec<String>backup_root: Option<String>operation_count: usizeoperation_counts: RestoreApplyOperationKindCountspending_operations: usizeready_operations: usizeblocked_operations: usizecompleted_operations: usizefailed_operations: usizeoperations: Vec<RestoreApplyJournalOperation>operation_receipts: Vec<RestoreApplyOperationReceipt>Implementations
Sourceimpl RestoreApplyJournal
impl RestoreApplyJournal
Sourcepub fn from_dry_run(dry_run: &RestoreApplyDryRun) -> Self
pub fn from_dry_run(dry_run: &RestoreApplyDryRun) -> Self
Build the initial no-mutation restore apply journal from a dry-run.
Sourcepub fn validate(&self) -> Result<(), RestoreApplyJournalError>
pub fn validate(&self) -> Result<(), RestoreApplyJournalError>
Validate the structural consistency of a restore apply journal.
Sourcepub fn next_command_preview(&self) -> RestoreApplyCommandPreview
pub fn next_command_preview(&self) -> RestoreApplyCommandPreview
Render the next transitionable operation as a no-execute command preview.
Sourcepub fn mark_next_operation_pending_at(
&mut self,
updated_at: Option<String>,
) -> Result<(), RestoreApplyJournalError>
pub fn mark_next_operation_pending_at( &mut self, updated_at: Option<String>, ) -> Result<(), RestoreApplyJournalError>
Mark the next transitionable operation pending with an update marker.
Sourcepub fn retry_failed_operation_at(
&mut self,
sequence: usize,
updated_at: Option<String>,
) -> Result<(), RestoreApplyJournalError>
pub fn retry_failed_operation_at( &mut self, sequence: usize, updated_at: Option<String>, ) -> Result<(), RestoreApplyJournalError>
Retry one failed restore apply operation by moving it back to ready.