pub struct RestoreApplyOperationKindCounts {
pub canister_stops: usize,
pub canister_starts: usize,
pub snapshot_uploads: usize,
pub snapshot_loads: usize,
pub member_verifications: usize,
pub deployment_verifications: usize,
pub verification_operations: usize,
}Expand description
RestoreApplyOperationKindCounts
Serializable operation-kind counter projection for restore apply journals. Owned by restore apply journaling and embedded in dry-run and journal outputs.
Fields
canister_stops: usizecanister_starts: usizesnapshot_uploads: usizesnapshot_loads: usizemember_verifications: usizedeployment_verifications: usizeverification_operations: usizeImplementations
Sourceimpl RestoreApplyOperationKindCounts
impl RestoreApplyOperationKindCounts
Sourcepub fn from_operations(operations: &[RestoreApplyJournalOperation]) -> Self
pub fn from_operations(operations: &[RestoreApplyJournalOperation]) -> Self
Count restore apply journal operations by runner operation kind.
Sourcepub fn validate_matches(
&self,
expected: &Self,
) -> Result<(), RestoreApplyJournalError>
pub fn validate_matches( &self, expected: &Self, ) -> Result<(), RestoreApplyJournalError>
Validate this count object against concrete operations.
Sourcepub fn from_dry_run_operations(
operations: &[RestoreApplyDryRunOperation],
) -> Self
pub fn from_dry_run_operations( operations: &[RestoreApplyDryRunOperation], ) -> Self
Count restore apply dry-run operations by runner operation kind.